@@ -206,7 +206,6 @@ void    ConSend(void)
 	memcpy (&send_msg.srcCall, &client_call, 8);
 	memcpy (&send_msg.dstCall, &CallerCall, 8);
 	memcpy (&send_msg.Rep1Call, &client_call, 8);
-	memcpy (&send_msg.dstRep, &CallerCall, 8);
         ret = sendto (udpSocket, (char *)&send_msg, sizeof (struct shm_form), 0,
                 (struct sockaddr *)&sndAddr, sizeof(sndAddr));
 }
@@ -226,7 +225,6 @@ void	AckSend(char srcRptCall[8], char PacketID[2])
 	ack_msg.PacketID[1] = PacketID[1];
         sendto (udpSocket, (char *)&ack_msg, sizeof(ack_msg), 0,
                  (struct sockaddr *)&sndAddr, sizeof(sndAddr));
-	return;
 }
 
 void    ReqSendSender()
@@ -310,7 +308,7 @@ int main(int argc, const char **argv){
 		now = time(NULL);
 		fprintf(logfile, "%24.24s Does not connect to '%s'.\n",ctime(&now), TrustDomainName);
 		fclose (logfile);
-	return(-1);
+		return(-1);
 	}
 
 	logfile = fopen (LOGFILE, "a");
@@ -545,9 +543,11 @@ int main(int argc, const char **argv){
 
 						if (send_packet.B_header.seq & 0x40)
 						{
-							fclose (dat);
-							dat = NULL;
-							dat = 0;
+							if (dat)
+							{
+								fclose (dat);
+								dat = NULL;
+							}
 							SendBack = TRUE;
 							Connected = FALSE;
 							ConnectWait = FALSE;
